Title: Book Review: Charles Murray's <em>Human Diversity: The Biology of Gender, Race, and Class</em>
Date: 2020-01-01
Category: commentary
Tags: Charles Murray, review (book), race, sex differences, Emacs, topology
Status: draft

[This is a pretty good book](https://www.twelvebooks.com/titles/charles-murray/human-diversity/9781538744000/) about things we know about some ways in which people are different from each other! In [my last book review](/2020/Jan/book-review-the-origins-of-unfairness/), I mentioned that I had been thinking about broadening the topic scope of this blog, and this book review seems like an okay place to start!

Honestly, I feel like I already knew most of this stuff?—sex differences in particular are kind of _my bag_—but many of the details were new to me, and it's nice to have it all bundled together in a paper book with lots of citations that I can chase down later when I'm skeptical or want more details about a specific thing! The main text is littered with pleonastic constructions like "The first author was Jane Thisand-Such" (when discussing the results of a multi-author paper) or "Details are given in the note<sup>[n]</sup>", which feel clunky to read, but are _so much better_ than the all-too-common alternative of authors _not_ "showing their work".

In the first part of this blog post, I'm going to summarize what I learned from (or was reminded of by) _Human Diversity_, but it would be kind of unhealthy for you to rely too much on tertiary blog-post summaries of secondary semi-grown-up-book literature summaries, so if these topics happen to strike your scientific curiosity, you should probably skip this post and [go buy the source material](https://www.amazon.com/dp/B07Y82KNS1/)—or maybe even a grown-up textbook!

The second part of this blog post is irrelevant.

-----

_Human Diversity_ is divided into three parts corresponding to the topics in the subtitle! (Plus another part if you want some wrapping-up commentary from Murray.) So the first part is about things we know about some ways in which female people and male people are different from each other!

The first (short) chapter is mostly about explaining [Cohen's _d_](https://en.wikiversity.org/wiki/Cohen%27s_d) [effect sizes](https://en.wikipedia.org/wiki/Effect_size), which I think are solving a very important problem! When people say "Men are taller than women" you know they don't mean _all_ men are taller than _all_ women (because you know that they know that that's obviously not true), but that just raises the question of what they _do_ mean. Saying they mean it "generally", "on average", or "statistically" doesn't really solve the problem, because that covers everything between-but-not-including "No difference" to "Yes, literally all women and all men". Cohen's _d_ is the summary statistic that lets us _quantify_ statistical differences in standardized form: once you can [visualize the overlapping distributions](https://rpsychologist.com/d3/cohend/), whether the reality of the data should be summarized in English words as a "large difference" or a "small difference" becomes a _much less interesting_ question.

Murray also addresses the issue of aggregating effect sizes—something [I've been meaning to get around to blogging about](/2018/Dec/untitled-metablogging-26-december-2018/#high-dimensional-social-science-and-the-conjunction-of-small-effect-sizes) more exhaustively for a while in this context of group differences (although at least, um, my favorite author on _Less Wrong_ [covered it in the purely abstract setting](https://www.lesswrong.com/posts/cu7YY7WdgJBs3DpmJ/the-univariate-fallacy)): small effect sizes in any single measurement can amount to a _big_ difference when you're considering many measurements at once. That's how people can distinguish female and male faces at 96% accuracy, even though there's no single measurement (like "eye width" or "nose height") offers that much predictive power.

[TODO: more examples of sex difference effect sizes, elaborate on "big" doesn't mean anything]

Subsequent chapers address sex differences in personality, cognition, interests, and the brain. It turns out that women are more warm, empathetic, æsthetically discerning, and cooperative than men are! They're also more into the Conventional, Artistic, and Social dimensions of the [Holland occupational-interests model](https://en.wikipedia.org/wiki/Holland_Codes).

You might think that this is all due to socialization, but then it's hard to explain why the same differences show up in different cultures—and why (counterintuitively) the differences seem _larger_ in richer, more feminist countries. (Although as evolutionary anthropologist [William Buckner](https://traditionsofconflict.com/) points out in [his](https://twitter.com/Evolving_Moloch/status/1228124441944584192) [social-media](https://twitter.com/Evolving_Moloch/status/1228860328483491840) [criticism](https://twitter.com/Evolving_Moloch/status/1228947493309698050) of _Human Diversity_, [W.E.I.R.D.](https://www.apa.org/monitor/2010/05/weird) samples from different countries aren't capturing the full range of human cultures.) You might think that the "larger differences in rich countries" result is an artifact: maybe people in less-feminist countries implicitly make within-sex comparisons when answering personality questions (_e.g._, "I'm aggressive _for a woman_") whereas people in more-feminist countries use a less sexist standard of comparison, construing ratings as compared to people-in-general. Murray points out that this explanation still posits the existence of large sex differences in rich countries (while explaining away the unexpected cross-cultural difference-in-differences). Another possibility is that wealth increases sexual dimorphism _in general_, including, _e.g._, height and blood pressure, not just in personality.

[TODO: tie into farmer/forager theory: http://www.overcomingbias.com/2010/10/divide-forager-v-farmer.html ]

Women are better at verbal ability and social cognition, whereas [men are better at visuospatial skills](http://zackmdavis.net/blog/2016/12/alpha-gamma-phi/). The sexes achieve similar levels of overall performance via somewhat different mental "toolkits." Murray devotes a section to a 2007 result of Johnson and Bouchard, who report that general intelligence ["masks the dimensions on which [sex differences in mental abilities] lie"](/papers/johnson-bouchard-sex_differences_in_mental_abilities_g_masks_the_dimensions.pdf): overall levels of mental well-functioning lead to underestimates of the effect sizes of specific mental abilities, which you want to statistically correct for. This result in particular is _super gratifying_ to me personally, because [I independently had a very similar idea a few months back](/2019/Sep/does-general-intelligence-deflate-standardized-effect-sizes-of-cognitive-sex-differences/)—it's _super validating_ as an amateur to find that the pros have been thinking along the same track!

The second part of the book is about some ways in which people with different ancestries are different from each other! Obviously, there are no "distinct" "races" (that would be dumb), but it turns out (as found by endeavors such as [Li _et al._ 2008](/papers/li_et_al-worldwide_human_relationships_inferred.pdf)) that when you throw clustering and [dimensionality-reduction](https://en.wikipedia.org/wiki/Dimensionality_reduction) algorithms at SNP data (<em>s</em>ingle <em>n</em>ucleotide <em>p</em>olymorphisms, places in the genome where more than one allele has non-negligible frequency), you get groupings that are a pretty good match to classical or self-identified "races".

Ask the computer to assume that an individual's ancestry came from _K_ fictive ancestral populations where _K_ := 2, and it'll infer that sub-Saharan Africans are descended entirely from one, East Asians and some native Americans are descended entirely from the other, and everyone else is an admixture. But if you set _K_ := 3, populations from Europe and the near East (which were construed as admixtures in the _K_ := 2 model) split off as a new inferred population cluster. And so on.

These ancestry groupings _are_ a "construct" in the sense that the groupings aren't "ordained by God"—the algorithm can find _K_ groupings for your choice of _K_—but _where_ it [draws those category boundaries](https://www.lesswrong.com/posts/d5NyJ2Lf6N22AD9PB/where-to-draw-the-boundary) is a function of the data. The construct is doing _cognitive work_, concisely summarizing statistical regularities in the dataset (which is _too large_ for humans to hold in their heads all at once): a map that reflects a territory.

Twentieth-century theorists like Fisher and Haldane and whatshisface-the-guinea-pig-guy had already figured out a lot about how evolution works (stuff like, a mutation that confers a fitness advantage of _s_ has a probability of about 2<em>s</em> of sweeping to fixation), but a lot of hypotheses about recent human evolution weren't easy to test or even formulate until the genome was sequenced!

You might think that there wasn't enough _time_ in the 2–5k generations since we came forth out of Africa for much human evolution to take place: a new mutation needs to confer an unusually large benefit to sweep to fixation that fast. But what if you didn't actually need any new mutations? Natural selection on polygenic traits can also act on "standing variation": variation _already_ present in the population that was mostly neutral in previous environments, but is fitness-relevant to new selection pressures. The rapid response to selective breeding observed in domesticated plants and animals mostly doesn't depend on new mutations.

Another mechanism of recent human evolution is _introgression_: early humans interbred with our Neanderthal and Denisovan "cousins", giving our lineage the chance to "steal" all their good alleles! In contrast to new mutations, which usually die out even when they're beneficial (that 2<em>s</em> rule again), alleles "flowing" from another population keep getting reintroduced, giving them more chances to sweep!

Population differences are important when working with genome-wide association studies, because a model "trained on" one population won't perform as well against the ["test set"](https://en.wikipedia.org/wiki/Training,_validation,_and_test_sets) of a different population. Suppose you do a big study and find a bunch of SNPs that correlate with a trait, like schizophrenia or liking opera. The frequencies of those SNPs for two populations from the same continent (like Japanese and Chinese) will hugely correlate (Pearson's _r_ ≈ 0.97), but for more genetically-distant populations from different continents, the correlation will still be big but not huge (like _r_ ≈ 0.8 or whatever).

What do these differences in SNP frequencies mean in practice?? We ... don't know yet. At least some population differences are fairly well-understood: I'd tell you about sickle-cell and lactase persistence, except [then I would have to scream](/2017/Dec/interlude-xi/). There are some cases where we see populations independently evolve different adaptations that solve the same problem: [people living on the plateaus of both Tibet and Peru have both adapted to high altitudes](https://www.pnas.org/content/104/suppl_1/8655.long), but the Tibetans did it by breathing faster and the Peruvians did it with more hemoglobin!

Sorry, "the Tibetans did it with ..." is sloppy phrasing on my part; what I actually mean is that the Tibetans who weren't genetically predisposed to breathe faster were more likely to die without leaving children behind. That's how evolution works!

The third part of the book is about genetic influences on class structure! Untangling the true causes of human variation is a really hard technical philosophy problem, but behavioral geneticists have at least gotten started with their simple _ACE_ model. It works like this: first, assume (that is, "pretend") that the genetic variation for a trait is _additive_ (if you have the appropriate SNP, you get more of the trait), rather than exhibiting _epistasis_ (where the effects of different loci interfere with each other) or Mendelian _dominance_ (where the presence of just one copy of an allele (of two) determines the phenotype, and it doesn't matter whether you heterozygously have a different allele as your second version of that gene). Then we pretend that we can partition the variance in phenotypes as the sum of the "additive" genetic variance _A_, plus the environmental variance "common" within a family _C_, plus "everything else" (including measurement "error" and the not-shared-within-families "environment") _E_. Briefly (albeit at the risk of being _cliché_): nature, nurture, and _noise_.

Then we can estimate the sizes of the _A_, _C_, and _E_ components by studying fraternal and identical twins. (If you hear people talking about "twin studies", this is what they mean—_not_ case studies of identical twins raised apart, which _are_ really cool but don't happen very often.) Both kinds of twins have the same family environment _C_ at the same time (parents, socioeconomic status, schools, _&c._), but identical twins are twice as genetically related to each other as fraternal twins, so the extent to which the identical twins are more similar is going to pretty much be because of their genes. "Pretty much" in the sense that while there are ways in which the assumptions of the model aren't quite true (assortative mating makes fraternal twins more similar in the ways their parents were _already_ similar before mating, identical twins might get treated more similarly by "the environment" on account of their appearance), the _quantitative_ effect of these deviations are probably pretty small!

Anyway, it turns out that the effect of the shared environment _C_ is way smaller than most people intuitively expect—next to zero for personality and adult intelligence. The environment matters—just not the part of the environment shared by sibling in the same family. Just not the part of the environment we know how to control. Thus, a lot of economic and class stratification actually ends up being along genetic lines: the nepotism of family wealth can buy opportunities and second chances, but it doesn't actually live your life for you.

<a id="heritability-caveats"></a>It's important not to overinterpret the heritability results; there are a bunch of standard caveats that go here that everyone's treatment of the topic needs to include! Heritability is about the _variance_ in phenotypes that can be predicted by _variance_ in genes. This is _not_ the same concept as "controlled by genes." To see this, notice that the trait "number of heads" has a heritability of zero because the variance is zero: all living people have exactly one head. (Siamese twins are two people.) Heritability estimates are also necessarily bound to a particular population in a particular place and time, which can face constraints shaped solely by the environment. If you plant half of a batch of seeds in the shade and half in the sun, the variance in the heights of the resulting plants will be associated with variance in genes _within_ each group, but the difference _between_ the groups is solely determined by the sunniness of their environments. Likewise, in a Society with a cruel caste system under which children with red hair are denied internet access, part of the heritability of intellectual achievement is going to come from alleles that code for red hair. Even though (_ex hypothesi_) redheads have the same inherent intellectual potential as everyone else, the heritability computation can't see into worlds that are not our own, which might have vastly different gene–environment correlations.

Old-timey geneticists used to think that they would find small number of "genes for" something, but it turns out that we live in an omnigenetic, pleiotropic world where lots and lots of SNPs each exert a tiny effect on potentially lots and lots of things. I feel like this probably _shouldn't_ have been surprising (genes code for amino-acid sequences, variation in what proteins get made from those amino-acid sequences is going to affect high-level behaviors, but high-level behaviors involve _lots_ of proteins in a super-complicated unpredictable way), but I guess it was.

Murray's penultimate chapter summarizes the state of a debate between a "Robert Plomin school" and an "Eric Turkheimer school" on the impact and import of polygenic scores, where we tally up all the SNPs someone has that are associated with a trait of interest.

The starry-eyed view epitomized by Plomin says that polygenic scores are _super great_ and everyone _and [her](TODO: linky "... and the Reverse Murray Rule") dog_ should be excited about them: they're causal in only one direction (the trait can't cause the score) and they let us assess risks in individuals before they happen. Clinical psychology will enter a new era of "positive genomics", where we understand how to work with the underlying dimensions along which people vary (including positively), rather than focusing on treated "diagnoses" that people allegedly "have".

The curmudgeonly view epitomized by Turkheimer says that Science is about understanding the _causal structure_ of phenomena, and that polygenic scores don't fucking tell us anything. [Marital status is heritable _in the same way_ that intelligence is heritable](http://www.geneticshumanagency.org/gha/the-ubiquity-problem-for-group-differences-in-behavior/), not because there are "divorce genes" in any meaningful biological sense, but because of a "universal, nonspecific genetic pull on everything": on average, people with more similar genes will make more similar proteins from those similar genes, and therefore end up with more similar phenotypes that interact with the environment in a more similar way, and _eventually_ (the causality flowing "upwards" through many hierarchical levels of organization) this shows up in the divorce statistics of a particular Society in a particular place and time. But this is completely opaque; the real work of Science is in figuring out what all the particular gene variations actually _do_.

Notably, Plomin and Turkheimer aren't actually disagreeing here: it's a difference in emphasis rather than facts. Polygenic scores _don't_ explain mechanisms—but might they end up being useful, and used, anyway? Murray's vision of social science is content to make predictions and "explain variance" while remaining ignorant of ultimate causality. Meanwhile, my cursory understanding (while kicking myself for [_still_](/2018/Dec/untitled-metablogging-26-december-2018/#daphne-koller-and-the-methods) not having put in the hours to get much farther into [_Probabilistic Graphical Models: Principles and Techniques_](https://mitpress.mit.edu/books/probabilistic-graphical-models)) was that you _need_ to understand causality in order to predict what interventions will have what effects: variance in rain may be statistically "explained by" variance in mud puddles, but you can't make it rain by turning the hose on. Maybe our feeble state of knowledge is _why_ we don't know how to find reliable large-effect environmental interventions that still yet might exist in the vastness of the space of possible interventions.

There are also some appendicies at the back of the book! Appendix 1 (reproduced from, um, one of Murray's earlier books with a coauthor) explains some basic statistics concepts. Appendix 2 ("Sexual Dimorphism in Humans") goes over the prevalence of intersex conditions and gays, and then—so much for this post broadening the [topic scope of this blog](/tag/two-type-taxonomy/)—transgender typology! Murray presents the Blanchard–Bailey–Lawrence–Littman view as fact, which I think is basically _correct_, but a more comprehensive treatment (which I concede may be too much too hope for from a mere Appendix) would have at least _mentioned_ alternative views ([Serano](https://rationalwiki.org/wiki/Intrinsic_Inclinations_Model)? [Veale](/papers/veale-lomax-clarke-identity_defense_model.pdf)?), if only to explain _why_ they're worth dismissing. (Contrast to the eight pages in the main text explaining why "But, but, epigenetics!" is worth dismissing.) Then Appendix 3 ("Sex Differences in Brain Volumes and Variance") has tables of brain-size data, and an explanation of the greater-male-variance hypothesis. Cool!

[TODO: X chromosome greater male]

-----

... and that's the book review that I would _prefer_ to write. A science review of a science book, for science nerds: the kind of thing that would have no reason to draw your attention if you're not _genuinely interested_ in Mahanalobis _D_ effect sizes or adaptive introgression or Falconer's formulas, for their own sake, or (better) for the sake of [compressing the length of the message needed to encode your observations](https://en.wikipedia.org/wiki/Minimum_message_length).

But that's not why you're reading this. That's not why Murray wrote the book. That's not even why _I'm_ writing this. We should hope—emphasis on the _should_—for a discipline of Actual Social Science, whose practitioners strive to report the truth, the whole truth, and nothing but the truth, with the same passionately dispassionate objectivity they might bring to the study of beetles, or algebraic topology—or that an alien superintelligence might bring to the study of humans.

We do not have a discipline of Actual Social Science. Possibly because we're not smart enough to do it, but perhaps more so because we're not smart enough to _want_ to do it. No one has an incentive to lie about the homotopy groups of an _n_-sphere. If you're asking questions about homotopy groups _at all_, you almost certainly care about getting _the right answer for the right reasons_. At most, you might be biased towards believing your own conjectures in the optimistic hope of achieving eternal algebraic-topology fame and glory, like Ruth Lawrence. But nothing about algebraic topology is going to be [_morally threatening_](/2019/Jan/interlude-xvi/) in a way that will leave you fearing that your ideological enemies have siezed control of the publishing-houses to plant lies in the textbooks to fuck with your head, or sobbing that a malicious God created the universe as a place of evil.

Okay, maybe that was a bad example; topology in general really is the kind of mindfuck that might be the design of an adversarial agency. (Remind me to tell you about the long line, which is like the line of real numbers, except much longer.)

In any case, as soon as we start to ask questions _about humans_—and far more so _identifiable groups_ of humans—we end up entering the domain of _politics_.

We really _shouldn't_. Everyone _should_ perceive a common interest in true beliefs—maps that reflect the territory, [simple theories](https://www.lesswrong.com/posts/f4txACqDWithRi7hs/occam-s-razor) that [predict our observations](https://www.lesswrong.com/posts/a7n8GdKiAZRX86T5A/making-beliefs-pay-rent-in-anticipated-experiences)—because beliefs that make accurate predictions are _useful_ for making good decisions. That's what "beliefs" are _for_, evolutionarily speaking: my analogues in humanity's environment of evolutionary adaptedness were better off believing that (say) the berries from some bush were good to eat if and only if the berries were _actually_ good to eat. If my analogues unduly-optimistically thought the berries were good when they actually weren't, they'd get sick (and lose fitness), but if they unduly-pessimistically thought the berries were not good when they actually were, they'd miss out on valuable calories (and fitness).

(Okay, this story is actually somewhat complicated by the fact that [evolution didn't "figure out" how to build brains](https://www.lesswrong.com/posts/gTNB9CQd5hnbkMxAG/protein-reinforcement-and-dna-consequentialism) that [keep track of probability and utility separately](https://plato.stanford.edu/entries/decision-theory/): my analogues in the environment of evolutionary adaptedness might also have been better off assuming that a rustling in the bush was a tiger, even if it usually wasn't a tiger, because failing to detect actual tigers was so much more costly than erroneously "detecting" an imaginary tiger. But let this pass.)

The problem is that, while any individual should always want true beliefs for _themselves_ in order to navigate the world, you might want _others_ to have false beliefs in order to trick them into _mis_-navigating the world in a way that benefits you. If I'm trying to sell you a used car, then—counterintuitively—I might not _want_ you to have accurate beliefs about the car, if that would reduce the sale price or result in no deal. If our analogues in the environment of evolutionary adaptedness regularly faced structurally similar situations, and if it's expensive to maintain two sets of beliefs (the real map for ourselves, and a fake map for our victims), we might end up with a tendency not just to be lying motherfuckers who decieve others, but also to _self_-decieve in situations where the fitness payoffs of tricking others outweighed those of being clear-sighted ourselves.

That's why we're not smart enough to want a discipline of Actual Social Science. The benefits of having a collective understanding of human behavior—a _shared_ map that reflects the territory that we are—could be enormous, but beliefs about our own qualities, and those of socially-salient groups to which we belong (_e.g._, sex, race, and class) are _exactly_ those for which we face the largest incentive to decieve and self-decieve. Counterintuively, I might not _want_ you to have accurate beliefs about the value of my friendship (or the disutility of my animosity), for the same reason that I might not want you to have accurate beliefs about the value of my used car. That makes it a lot harder not just to _get the right answer for the reasons_, but also to _trust_ that your fellow so-called "scholars" are trying to get the right answer, rather than trying to sneak self-aggrandizing lies into the shared map in order to fuck you over. You can't _just_ write a friendly science book for oblivious science nerds about "things we know about some ways in which people are different from each other", because almost no one is that oblivious. To write and be understood, you have to do some sort of _positioning_ of how your work fits in to [the war](/2020/Feb/if-in-some-smothering-dreams-you-too-could-pace/) over the shared map.

Murray positions _Human Diversity_ as a corrective to a "blank slate" orthodoxy that refuses to entertain any possibility of biological influences on psychological group differences. The three parts of the book are pitched not simply as "stuff we know about biologically-mediated group differences" (the oblivious-science-nerd approach that I would prefer), but as a rebuttal to "Gender Is a Social Construct", "Race Is a Social Construct", and "Class Is a Function of Privilege." At the same time, however, Murray is careful to position his work as _nonthreatening_: "there are no monsters in the closet," he writes, "no dread doors that we must fear opening." He likewise "state[s] explicitly that [he] reject[s] claims that groups of people, be they sexes or races or classes, can be ranked from superior to inferior [or] that differences among groups have any relevance to human worth or dignity."

I think this strategy is sympathetic but [ultimately ineffective](http://zackmdavis.net/blog/2016/08/ineffective-deconversion-pitch/). Murray is trying to have it both ways: challenging the orthodoxy, while denying the possibility of any [unfortunate implications](https://tvtropes.org/pmwiki/pmwiki.php/Main/UnfortunateImplications) of the orthodoxy being false. It's like ... [theistic evolution](https://en.wikipedia.org/wiki/Theistic_evolution): satisfactory as long as you _don't think about it too hard_, but among those with a high [need for cognition](https://en.wikipedia.org/wiki/Need_for_cognition), who know what it's like to truly believe (as I once believed), it's not going to convince anyone who hasn't _already_ broken from the orthodoxy.

Murray concludes, "Above all, nothing we learn will threaten human equality properly understood." I [_strongly_ agree with](/2017/Dec/theres-a-land-that-i-see-or-the-spirit-of-intervention/) the _moral sentiment_, the underlying [axiology](https://slatestarcodex.com/2017/08/28/contra-askell-on-moral-offsets/) that makes this seem like a good and wise thing to say.

And yet I have been ... [trained](https://www.lesswrong.com/posts/teaxCFgtmCQ3E9fy8/the-martial-art-of-rationality). Trained to instinctively apply my full powers of analytical rigor and skepticism [to even that which is most sacred](https://www.lesswrong.com/posts/dHQkDNMhj692ayx78/avoiding-your-belief-s-real-weak-points). Because my true loyalty is to the axiology—[to the _process_ underlying my _current best guess_](http://zackmdavis.net/blog/2017/03/dreaming-of-political-bayescraft/) as to that which is most sacred. If that which was believed to be most sacred turns out to not be entirely coherent ... then we might have some philosophical work to do, to [_reformulate_ the sacred moral ideal in a way that's actually coherent](https://arbital.greaterwrong.com/p/rescue_utility).

"Nothing we learn will threaten _X_ _properly understood_." When you elide the specific assignment _X_ := "human equality", the _form_ of this statement is kind of suspicious, right? Why "properly understood"? It would be weird to say, "Nothing we learn will threaten the homotopy groups of an _n_-sphere _properly understood_."

This kind of [claim to be non-disprovable](https://www.lesswrong.com/posts/fAuWLS7RKWD2npBFR/religion-s-claim-to-be-non-disprovable) seems like the kind of thing you would only invent if you _were_ secretly worried about _X_ being threatened by new discoveries, and wanted to protect your ability to backtrack and [re-gerrymander your definition of _X_ to protect what you](https://www.lesswrong.com/posts/esRZaPXSHgWzyB2NL/where-to-draw-the-boundaries) ([think that you](https://www.lesswrong.com/posts/CqyJzDZWvGhhFJ7dY/belief-in-belief)) currently believe.

If being an oblivious science nerd isn't an option, half-measures won't suffice. I think we can do better by going meta and analyzing the _functions_ being served by the constraints on our discourse and seeking out clever self-aware strategies for satisfying those functions _without_ [lying about everything](/2017/Jan/im-sick-of-being-lied-to/). We mustn't fear opening the dread meta-door in front of whether there actually _are_ dread doors that we must fear opening.

Why _is_ the blank slate doctrine so compelling, that so many feel the need to protect it at all costs? (As I once felt the need.) It's not ... if you've read this far, I assume you _will_ forgive me—it's not _scientifically_ compelling. If you were studying humans the way an alien superintelligence would, trying to _get the right answer for the right reasons_ (which can conclude _conditional_ answers: if what humans are like depends on _choices_ about what we teach our children, then there will still be a fact of the matter as to what choices lead to what outcomes), you wouldn't put a whole lot of prior probability on the hypothesis "Both sexes and all ancestry-groupings of humans have the same distribution of psychological predispositions; any observed differences in behavior are solely attributable to differences in their environments." _Why_ would that be true? We _know_ that sexual dimorphism exists. We _know_ that reproductively isolated populations evolve different traits to adapt to their environments, like [those birds with differently-shaped beaks that Darwin saw on his boat trip](https://en.wikipedia.org/wiki/Darwin%27s_finches). We could certainly _imagine_ that none of the relevant selection pressures on humans happened to touch the brain—but why? Wouldn't that be kind of a weird coincidence?

If the blank slate doctrine isn't _scientifically_ compelling—it's not something you would invent while trying to build shared maps that reflect the territory—then its appeal must have something to do with some function it plays in _conflicts_ over the shared map, where no one trusts each other to be doing Actual Social Science rather than lying to fuck everyone else over.

And that's where the blank slate doctrine absolutely _shines_—it's the [Schelling point](/2019/Oct/self-identity-is-a-schelling-point/) for preventing group conflicts! (A [_Schelling point_](https://www.lesswrong.com/posts/yJfBzcDL9fBHJfZ6P/nash-equilibria-and-schelling-points) is a choice that's salient as [a focus for mutual expectations](/2019/Dec/more-schelling/): what I think that you think that I think ... _&c._ we'll choose.) If you admit that there could differences between groups, you open up the questions of in what exact traits and of what exact magnitude, which people have an incentive to lie about to divert resources and power to their group by [establishing unfair conventions and then misrepresenting those contingent bargaining equilibria](/2020/Jan/book-review-the-origins-of-unfairness/) as some "inevitable" natural order.

If you're afraid of purported answers being used as a pretext for oppression, you might hope to _make the question un-askable_. Can't oppress people on the basis of race if race _doesn't exist_! Denying the existence of sex is harder—which doesn't stop people from occasionally trying. But the taboo mostly only applies to _psychological_ trait differences, because those are more [politically sensitive](http://benjaminrosshoffman.com/judgment-punishment-and-the-information-suppression-field/)—and easier to motivatedly _see what you want to see_: whereas things like height or skin tone can be directly seen and uncontroversially measured with well-understood physical instruments (like a meterstick or digital photo pixel values), psychological assessments are _much_ more complicated and therefore hard to detach from the eye of the beholder. (If I describe Mary as "warm, compassionate, and agreeable", the words mean _something_ in the sense that they change what experiences you anticipate—if you believed my report, you would be _surprised_ if Mary were to kick your dog and make fun of your nose job—but the things that they mean are a high-level statistical signal in behavior for which we [don't have a simple measurement device](https://www.lesswrong.com/posts/edEXi4SpkXfvaX42j/schelling-categories-and-simple-membership-tests) like a meterstick to appeal to if you and I don't trust each other's character assessments of Mary.)

Notice how the "not allowing sex and race differences in psychological traits to appear on shared maps is the Schelling point for resistance to sex- and race-based oppression" actually gives us an _explanation_ for _why_ one might reasonably have a sense that there are dread doors that we must not open. Undermining the "everyone is Actually Equal" Schelling point could [catalyze a preference cascade](https://www.reddit.com/r/slatestarcodex/comments/8q8p6n/culture_war_roundup_for_june_11/e0mxwe9/)—a [slide down the slippery slope to the the next Schelling point](https://www.lesswrong.com/posts/Kbm6QnJv9dgWsPHQP/schelling-fences-on-slippery-slopes), which might be a lot worse than the _status quo_ on the "amount of rape and genocide" metric, even if it does slightly better on "estimating heritability coefficients." The orthodoxy isn't just being dumb for no reason. In analogy, Galileo and Darwin weren't _trying_ to undermine Christianity—they had much more interesting things to think about—but religious authorities were _right_ to fear heliocentrism and evolution: if the prevailing coordination equilibrium depends on lies, then telling the truth _is_ a threat and it _is_ disloyal. And if the prevailing coordination equilibrium is basically _good_, then you can see why purported truth-tellers striking at the heart of the faith might be believed to be evil.

Murray opens the parts of the book about sex and race with acknowledgements of the injustice of historical patriarchy ("When the first wave of feminism in the United States got its start [...] women were rebelling not against mere inequality, but against near-total legal subservience to men") and racial oppression ("slavery experienced by Africans in the New World went far beyond legal constraints [...] The freedom granted by emancipation in America was only marginally better in practice and the situation improved only slowly through the first half of the twentieth century"). It feels ... defensive? Coerced? It probably _is_ coerced. (To his credit, Murray is generally pretty forthcoming about how the need to write "defensively" shaped the book, as in a sidebar in the introduction that says that he's prefer to say a lot more about evopsych, but he chose to just focus on empirical findings in order to avoid the charge of telling "just-so stories.")

But this kind of defensive half-measure satisfies no one. From the oblivious-science-nerd perspective—the view that agrees with Murray that "everyone should calm down"—you shouldn't _need_ to genuflect to the memory of some historical injustice before you're allowed to talk about Science. But from the perspective that cares about Justice and not just Truth, an _insincere_ gesture or a strategic concession is all the more dangerous insofar as it could function as camoflage for a nefarious hidden agenda. If your work is explicitly aimed at _destroying the anti-oppression Schelling-point belief_, a few hand-wringing historical interludes and bromides about human equality having no testable implications (!!) aren't going to clear you of the suspicion that you're _doing it on purpose_—trying to destroy the anti-oppression Schelling point in order to oppress, not because anything that can be destroyed by the truth, should be.

And sufficient suspicion makes communication nearly impossible. (If you _know_ someone is lying, their words mean nothing, [not even as the opposite of the truth](https://www.lesswrong.com/posts/qNZM3EGoE5ZeMdCRt/reversed-stupidity-is-not-intelligence).) As far as many of Murray's detractors are concerned, it almost doesn't matter what the text of _Human Diversity_ says, how meticulously researched of a psychology/neuroscience/genetics lit review it is. From their perspective, Murray is "hiding the ball": they're not mad about _this_ book; they're mad about specifically chapters 13 and 14 of a book Murray coauthored twenty-five years ago. (I don't think I'm claiming to be a mind-reader here; the first 20% of [_The New York Times_'s review of _Human Diversity_](https://archive.is/b4xKB) is pretty explicit and representative.)

In 1994's _The Bell Curve: Intelligence and Class Structure in American Life_, Murray and coauthor Richard J. Herrnstein argued that a lot of variation in life outcomes is explained by variation in intelligence. Some people think that folk concepts of "intelligence" or being "smart" are ill-defined and therefore not a proper object of scientific study. But that hasn't stopped some psychologists from trying to construct tests purporting to measure an "intelligence quotient" (or _IQ_ for short). It turns out that if you give people a bunch of different mental tests, the results all positively correlate with each other: people who are good at one mental task, like listening to a list of numbers and repeating them backwards ("reverse digit span"), are also good at others, like knowing what words mean ("vocabulary"). There's a lot of fancy linear algebra involved, but basically, you can visualize people's test results as a hyperellipsoid in some high-dimensional space where the dimensions are the different tests. (I rely on this ["configuration space"](https://www.lesswrong.com/posts/WBw8dDkAWohFjWQSk/the-cluster-structure-of-thingspace) visual metaphor _so much_ for _so many_ things that when I started [my secret ("secret") gender blog](/), it felt right to put it under a dot-space [TLD](https://en.wikipedia.org/wiki/Top-level_domain).) The longest axis of the hyperellipsoid corresponds to the "_g_ factor" of "general" intelligence—the choice of axis that cuts through the most variance in mental abilities.

So Murray and Herrnstein talk about this "intelligence" thingy, and how it's heritable, and how it predicts income, school success, not being a criminal, _&c._, and how this has all sorts of implications for Society and inequality and class structure and stuff.

This _should_ just be more social-science nerd stuff, the sort of thing that would only draw your attention if, like me, you feel bad about not being smart enough to do algebraic topology and want to console yourself by at least knowing about the Science of not being smart enough to do algebraic topology. The reason everyone _and her dog_ is still mad at Charles Murray a quarter century later is Chapter 13, "Ethnic Differences in Cognitive Ability", and Chapter 14, "Ethnic Inequalities in Relation to IQ". So, _apparently_, different ethnic/"racial" groups have different average scores on IQ tests. [Ashkenazi Jews do the best](https://slatestarcodex.com/2017/05/26/the-atomic-bomb-considered-as-hungarian-high-school-science-fair-project/), which is why I sometimes privately joke that the fact that I'm [only 85% Ashkenazi (according to 23andMe)](/images/ancestry_report.png) explains my low IQ. (I'm pretty dumb compared to some of my [robot-cult](/tag/my-robot-cult/) friends.) East Asians do a little better than Europeans/"whites". And—this is the part that no one is happy about—the difference between U.S. whites and U.S. blacks is about Cohen's _d_ ≈ 1. (If two groups differ by _d_ = 1 on some measurement that's normally distributed within each group, that means that the mean of the group with the lower average measurement is at the 16th percentile of the group with the higher average measurement, or that a uniformly-randomly selected member of the group with the higher average measurement has a probability of about 0.76 have having a higher measurement than a uniformly-randomly selected member of the group with the lower average measurement.)

It's important not to overinterpret the IQ-scores-by-race results; there are a bunch of standard caveats that go here that everyone's treatment of the topic needs to include. Again, just because variance in a trait is statistically associated with variance in genes _within_ a population, does _not_ mean that differences in that trait _between_ populations are _caused_ by genes: [remember the illustrations about](#heritability-caveats) sun-deprived plants and internet-deprived red-haired children. Group differences in observed tested IQs are entirely compatible with a world in which those differences are entirely due to the environment imposed by an overtly or structurally racist society. Maybe the tests are culturally biased. Maybe people with higher socioeconomic status get more opportunities to develop their intellect, and racism impedes socio-economic mobility. And so on.

The problem is, a lot of the blank-slatey environmentally-caused-differences-only hypotheses for group IQ differences become less compelling when you look into the details. "Maybe the tests are biased", for example, isn't an insurmountable defeater to the entire endeavor of IQ testing—it is _itself_ a falsifiable hypothesis, or can become one if you specify what you mean by "bias" in detail. One idea of what it would mean for a test to be _biased_ is if it's partially measuring something other than what it purports to be measuring: if your test measures a _combination_ of "intelligence" and "submission to the hegemonic cultural dictates of the test-maker", then individuals and groups that submit less to your cultural hegemony are going to score worse, and if you _market_ your test as unbiasedly measuring intelligence, then people who believe your marketing copy will be misled into thinking that those who don't submit are dumber than they really are. But if so, and if not all of your individual test questions are _equally_ loaded on intelligence and cultural-hegemony, then the cultural bias should _show up in the statistics_. If some questions are more "fair" and others are relatively more culture-biased, then you would expect the _order of item difficulties_ to differ by culture: the ["item characteristic curve"](/papers/baker-kim-the_item_characteristic_curve.pdf) plotting the probability of getting the biased question "right" as a function of _overall_ test score should differ by culture, with the hegemonic group finding it "easier" and others (answering honestly) finding it "harder". Conversely, if the questions that discriminate most between differently-scoring cultural/ethnic/"racial" groups were the same as the questions that discriminate between (say) younger and older children _within_ each group, that would be the kind of statistical clue you would expect to see if the test was unbiased and the group difference was real. Hypotheses that accept IQ test results as unbiased, but attribute group differences to the environment, also make statistical predictions. Controlling for parental socioeconomic status only cuts the black–white gap by a third.

[TODO: sentence about sources of variation within/between groups based on Jensen]

[TODO: sentence about colorism based on https://www.mdpi.com/2624-8611/1/1/17/htm "Skin color is actually only controlled by a small number of alleles, so if you think societal discrimination on skin color causes IQ differences"]

And so on.

In mentioning these arguments in passing, I'm _not_ trying to provide a comprehensive lit review on the causality of group IQ differences. (That's [someone else's blog](https://humanvarieties.org/2019/12/22/the-persistence-of-cognitive-inequality-reflections-on-arthur-jensens-not-unreasonable-hypothesis-after-fifty-years/).) I'm not (that) interested in this particular topic. I am ... doing some context-setting for the problem I am interested in, of fixing public discourse. The reason we can't have an intellectually-honest public discussion about human biodiversity is because good people want to respect the anti-oppression Schelling point and are afraid of giving ammunition to racists and sexists in the war over the shared map. "Black people are genetically less intelligent than white people, on average" is the kind of sentence that pretty much only racists would feel _good_ about saying out loud, independently of its actual truth value. In a world where most speech is about manipulating shared maps for political advantage rather than _getting the right answer for the right reasons_, it is _rational_ to infer that anyone who entertains such hypotheses is either motivated by racial malice, or is at least complicit with it—and that rational expectation isn't easily cancelled with a _pro forma_ "But civil discourse" or "But the true meaning of Equality is unfalsifiable" disclaimer.

To speak to those who aren't _already_ oblivious science nerds—or are committed to emulating such, as it is scientifically dubious whether anyone is really that oblivious—you need to put _more effort_ into your excuse for why you're interested in these topics. Here's mine, and it's from the heart, though it's up to the reader to judge for herself how credible I am when I say this—

I don't want to be complicit with hatred or oppression. I want to stay loyal to the underlying egalitarian–individualist axiology that makes the blank slate doctrine _sound like a good idea_. But I also want to understand reality, to make sense of things. I want a world that's not lying to me. Having to believe false things—or even just not being able _say_ certain true things when they would otherwise be relevant—extracts a _dire_ cost on our ability to make sense of the world, because you can't just censor a few forbidden hypotheses—[you have to censor everything that _implies_ them](https://www.lesswrong.com/posts/wyyfFfaRar2jEdeQK/entangled-truths-contagious-lies), and everything that implies _them_: the more adept you are at making logical connections, [the more of your mind you need to excise to stay in compliance](https://www.lesswrong.com/posts/XTWkjCJScy2GFAgDt/dark-side-epistemology).

We can't talk about group differences, for fear that belief in differences will be abused to shore up oppression. But ... structural oppression and actual group differences can _both exist at the same time_. They're not contradicting each other! Like, the fact that men are physically stronger than women (on average, but the effect size is really big, like _d_ ≈ [TODO: size] for [TODO: operationalization]) is _not unrelated_ to the persistence of patriarchy! That doesn't mean patriarchy is good! [(You can't derive an _ought_ from an _is_.)](https://plato.stanford.edu/entries/hume-moral/#io) This is pretty obvious, really? 
